* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Searching and Filtering in the Inventory](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory)
  * Advanced Filter Options
